+++
date = "2019-11-26"
weight = 100

title = "Guidelines"

aliases = [
    "/old-wiki/Guidelines"
]
+++

# Guidelines

SDK guidelines for application developers, focusing on security. These
are a series of guidelines and examples for various aspects of
developing on and in the Apertis libraries and applications. They assume
a good level of competence with programming in C, and familiarity with
the underlying libraries Apertis uses, such as
[GLib](https://developer.gnome.org/glib/stable/). A good set of
introductory guidelines for using GLib and related libraries are the
[GNOME Programming
Guidelines](https://developer.gnome.org/programming-guidelines/unstable/).

To get started, skim each of the [General
guidelines](#general-guidelines) pages, each of which has a
summary at the top. Specific topics are covered in the [Specific
how-tos](#specific-how-tos) section, which can be used more
like a reference manual.

The [external links](#external-links) point to further
resources, which can be quite comprehensive and are worth reading.

## General guidelines

  - [How to submit a patch in Apertis
    project](https://designs.apertis.org/latest/contribution-process.html)
  - [Packaging release
    workflow]( {{< ref "/guidelines/howtoreleasepackages.md" >}} )
  - [Module setup]( {{< ref "/guidelines/module_setup.md" >}} )
  - [Licensing](https://designs.apertis.org/latest/license-applying.html)
  - [Coding
    conventions](https://designs.apertis.org/latest/coding_conventions.html)
  - [Upstream
    first](https://designs.apertis.org/latest/contribution-process.html#upstream-first-policy)
  - [Version control]( {{< ref "/guidelines/version_control.md" >}} )
  - [API design]( {{< ref "/guidelines/api_design.md" >}} )
  - [API stability]( {{< ref "/guidelines/api_stability.md" >}} )
  - [Memory management]( {{< ref "/guidelines/memory_management.md" >}} )
  - [Tooling]( {{< ref "/guidelines/tooling.md" >}} )
  - [Unit testing]( {{< ref "/guidelines/unit_testing.md" >}} )
  - [API documentation]( {{< ref "/guidelines/api_documentation.md" >}} )
  - [Code submission
    checklist](https://designs.apertis.org/latest/contribution-checklist.html)

## Specific how-tos

  - [How to develop on
    devices]( {{< ref "/guidelines/howtodevelopondevices.md" >}} )
  - [Enabling new hardware]( {{< ref "/enabling_new_hardware.md" >}} )
  - [Package maintenance]( {{< ref "/package_maintenance.md" >}} )
  - [JSON parsing]( {{< ref "/guidelines/json_parsing.md" >}} )
  - [XML parsing]( {{< ref "/guidelines/xml_parsing.md" >}} )
  - [GSettings]( {{< ref "/guidelines/gsettings.md" >}} )
  - [D-Bus services]( {{< ref "/guidelines/d-bus_services.md" >}} )
  - [Introspection]( {{< ref "/guidelines/introspection.md" >}} )
  - [SQLite]( {{< ref "/guidelines/sqlite.md" >}} )
  - [Tracker]( {{< ref "/guidelines/tracker.md" >}} )
  - [AppArmor]( {{< ref "/guidelines/apparmor.md" >}} )
  - [Threading]( {{< ref "/guidelines/threading.md" >}} )
  - [Filesystem access]( {{< ref "/guidelines/filesystem_access.md" >}} )
  - [Logging]( {{< ref "/guidelines/logging.md" >}} )
  - [Internationalization]( {{< ref "/guidelines/internationalization.md" >}} )
  - [Processes]( {{< ref "/guidelines/processes.md" >}} )
  - [Writing documentation in Mallard]( {{< ref "/mallard.md" >}} )
  - [Writing test cases]( {{< ref "/qa/test_cases_guidelines.md" >}} )
  - [Add linters to a project]( {{< ref "/guidelines/add_linters_to_a_project.md" >}} )
  - [Building, Patching And Maintaining The Apertis
    Kernel]( {{< ref "/guidelines/buildingpatchingandmaintainingtheapertiskernel.md" >}} )

## External links

  - [CERT secure C coding guidelines](https://www.securecoding.cert.org/confluence/display/seccode/CERT+C+Coding+Standard)
  - [MISRA C coding guidelines overview](http://en.wikipedia.org/wiki/MISRA_C) (guidelines themselves are non-free)
  - [GNOME Programming Guidelines](https://developer.gnome.org/programming-guidelines/unstable/)
  - [Google C++ guidelines](https://google.github.io/styleguide/cppguide.html#General_Naming_Rules)
    — useful general advice, but often not specific to GLib-style C, and
    sometimes contradictory to the GNOME Programming Guidelines, which
    are preferred
